"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var Rollbar = require("rollbar");
var rollbar_config_1 = require("./rollbar.config");
/**
 * Rollbar Logging Service.
 *
 * Wraps the logging functions of Rollbar in an Angular 2+ service to make
 * things a little smoother.
 * Follows the Rollbar browser API as closely as possible.
 */
var RollbarService = (function () {
    /**
     * Creates an instance of RollbarService.
     *
     * @param {RollbarConfig} options The configuration options for your Rollbar
     * account.
     *
     * @memberOf RollbarService
     */
    function RollbarService(options) {
        this.rollbar = Rollbar.init(options);
    }
    /**
     * Sets Rollbar configuration options at runtime.
     *
     * @param options A partial configuration object
     */
    RollbarService.prototype.configure = function (options) {
        return this.rollbar.configure(options);
    };
    RollbarService.prototype.handleError = function (err) {
        this.rollbar.error(err.originalError || err);
    };
    /**
       * Logs a message to Rollbar at the default log level
       *
       * @param {String} message The content of the message
       * @param {Error} [error] An exception to pass along with the message
       * @param {Object} [data] Custom data object to log with the message
       * @param {Function} [callback] If you aren't into promises, provide a callback.
       * @returns
       *
       * @memberOf RollbarService
       */
    RollbarService.prototype.log = function (message, error, data, callback) {
        return this.rollbar.log(message, error, data, callback);
    };
    /**
       * Logs an info level log message to Rollbar
       *
       * @param {String} message The content of the message
       * @param {Error} [error] An exception to pass along with the message
       * @param {Object} [data] Custom data object to log with the message
       * @param {Function} [callback] If you aren't into promises, provide a callback.
       * @returns
       *
       * @memberOf RollbarService
       */
    RollbarService.prototype.info = function (message, error, data, callback) {
        return this.rollbar.info(message, error, data, callback);
    };
    /**
       * Logs a WARN level log message to Rollbar
       *
       * @param {String} message The content of the message
       * @param {Error} [error] An exception to pass along with the message
       * @param {Object} [data] Custom data object to log with the message
       * @param {Function} [callback] If you aren't into promises, provide a callback.
       * @returns
       *
       * @memberOf RollbarService
       */
    RollbarService.prototype.warn = function (message, error, data, callback) {
        return this.rollbar.warn(message, error, data, callback);
    };
    /**
       * Logs an ERROR level log message to Rollbar
       *
       * @param {String} message The content of the message
       * @param {Error} [error] An exception to pass along with the message
       * @param {Object} [data] Custom data object to log with the message
       * @param {Function} [callback] If you aren't into promises, provide a callback.
       * @returns
       *
       * @memberOf RollbarService
       */
    RollbarService.prototype.error = function (message, error, data, callback) {
        return this.rollbar.error(message, error, data, callback);
    };
    /**
       * Logs a CRITICAL ERROR log message to Rollbar
       *
       * @param {String} message The content of the message
       * @param {Error} [error] An exception to pass along with the message
       * @param {Object} [data] Custom data object to log with the message
       * @param {Function} [callback] If you aren't into promises, provide a callback.
       * @returns
       *
       * @memberOf RollbarService
       */
    RollbarService.prototype.critical = function (message, error, data, callback) {
        return this.rollbar.critical(message, error, data, callback);
    };
    RollbarService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    RollbarService.ctorParameters = function () { return [
        { type: rollbar_config_1.RollbarConfig, },
    ]; };
    return RollbarService;
}());
exports.RollbarService = RollbarService;
//# sourceMappingURL=rollbar.service.js.map